<?php
/**
 * EduMag Pro Search Section Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add search section enable section
$wp_customize->add_section( 'edumag_pro_search_section', array(
  'title'             => esc_html__( 'Search Section','edumag-pro'),
  'description'       => esc_html__( 'Search section options.', 'edumag-pro' ),
  'panel'             => 'edumag_pro_sections_panel'
) );

// Add search section enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_enable]', array(
  'default'           => $options['search_section_enable'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[search_section_enable]', array(
  'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'select',
  'choices'           => edumag_pro_enable_disable_options()
) );

// Add search section title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_title]', array(
  'default'           => $options['search_section_title'],
  'transport'         => 'postMessage',
  'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[search_section_title]', array(
  'label'             => esc_html__( 'Title', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'active_callback'   => 'edumag_pro_is_search_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
  $wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[search_section_title]', array(
    'selector'            => '#fixed-background h2.entry-title',
    'render_callback'     => 'edumag_pro_customize_partial_search_section_title',
    'container_inclusive' => false,
    'fallback_refresh'    => true,
  ) );
}

// Add search section sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_subtitle]', array(
  'default'           => $options['search_section_subtitle'],
  'transport'         => 'postMessage',
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[search_section_subtitle]', array(
  'label'             => esc_html__( 'Description', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'textarea',
  'active_callback'   => 'edumag_pro_is_search_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
  $wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[search_section_subtitle]', array(
    'selector'            => '#fixed-background p.sub-title',
    'render_callback'     => 'edumag_pro_customize_partial_search_section_subtitle',
    'container_inclusive' => false,
    'fallback_refresh'    => true,
  ) );
}

// Add search section search options heading setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_search_options_heading]', array(
  'sanitize_callback' => 'esc_html'
) );


$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[search_section_search_options_heading]', array(
  'label'             => esc_html__( 'Search Options', 'edumag-pro' ),
  'description'       => esc_html__( 'Option to customize search in and search text options.', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'description',
  'active_callback'   => 'edumag_pro_is_search_section_active',
) ) );


// Add search section post type setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_search_in]', array(
  'default'           => $options['search_section_search_in'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[search_section_search_in]', array(
  'label'             => esc_html__( 'Search Post In', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'select',
  'choices'           => array(
      'all'           => esc_html__( 'Only Posts', 'edumag-pro' ),
      'custom-posts'  => esc_html__( 'Custom Post Type', 'edumag-pro' )
  ),
  'active_callback'   => 'edumag_pro_is_search_section_active',
) );

// Add search section enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_custom_post]', array(
  'sanitize_callback' => 'edumag_pro_sanitize_custom_post_type'
) );

$wp_customize->add_control( new Edumag_Pro_Select_Custom_Post_Type( $wp_customize, 'edumag_pro_theme_options[search_section_custom_post]', array(
  'label'             => esc_html__( 'Select Custom Post Type', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'custom-post-type',
  'active_callback'   => 'edumag_pro_is_search_section_custom_post_active',
) ) );

// Add search section title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_button_text]', array(
  'default'           => $options['search_section_button_text'],
  'transport'         => 'postMessage',
  'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[search_section_button_text]', array(
  'label'             => esc_html__( 'Search Text', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'active_callback'   => 'edumag_pro_is_search_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
  $wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[search_section_button_text]', array(
    'selector'            => '#fixed-background button.btn-orange',
    'render_callback'     => 'edumag_pro_customize_partial_search_section_button_text',
    'container_inclusive' => false,
    'fallback_refresh'    => true,
  ) );
}

// Add search section background property heading setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_background_property]', array(
  'sanitize_callback' => 'esc_html'
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[search_section_background_property]', array(
  'label'             => esc_html__( 'Background Properties', 'edumag-pro' ),
  'description'       => esc_html__( 'Background properties for search section.', 'edumag-pro' ),
  'section'           => 'edumag_pro_search_section',
  'type'              => 'description',
  'active_callback'   => 'edumag_pro_is_search_section_active',
) ) );

// Add background image setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[search_section_background_image]', array(
  'default'           => $options['search_section_background_image'],
  'sanitize_callback' => 'edumag_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'edumag_pro_theme_options[search_section_background_image]',
    array(
    'label'           => esc_html__( 'Upload a Advertisement Image', 'edumag-pro' ),
    'description'     => esc_html__( 'Recommended advertisement image size is 1918x878 px', 'edumag-pro' ),
    'section'         => 'edumag_pro_search_section',
    'active_callback' => 'edumag_pro_is_search_section_active',
   )
) );