<?php
/**
 * Popular articles section
 *
 * This is the template for the content of Popular articles section
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! function_exists( 'edumag_pro_add_popular_articles_section' ) ) :
  /**
   * Add Popular articles section
   *
   * @since EduMag Pro 1.0
   */
  function edumag_pro_add_popular_articles_section() {

    // Check if Popular articles is enabled on frontpage
    $featured_category_enable = apply_filters( 'edumag_pro_section_status', true, 'popular_articles_enable' );
    if ( true !== $featured_category_enable ) {
      return false;
    }

    // Get Popular articles section details
    $section_details = array();
    $section_details = apply_filters( 'edumag_pro_filter_popular_articles_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render Popular articles section now.
    edumag_pro_render_popular_articles_section( $section_details );
  }
endif;
add_action( 'edumag_pro_primary_content', 'edumag_pro_add_popular_articles_section', 20 );

if ( ! function_exists( 'edumag_pro_get_popular_articles_section_details' ) ) :
  /**
   * Popular articles section details.
   *
   * @since EduMag Pro 1.0
   * @param array $input Popular articles section details.
   */
  function edumag_pro_get_popular_articles_section_details( $input ) {
    $options = edumag_pro_get_theme_options();

    // Popular articles type
    $popular_articles_content_type = $options['popular_articles_content_type'];

    $content = array();
    switch ( $popular_articles_content_type ) {
      case 'demo':
        $tabs = array(
           'all' => array(
                'value' => 'all-popular-article',
                'label' => esc_html__( 'All', 'edumag-pro' )
            ),
            'college' => array(
                'value' => 'tab-college',
                'label' => esc_html__( 'College', 'edumag-pro' )
            ),
            'careers' => array(
                'value' => 'tab-careers',
                'label' => esc_html__( 'Careers', 'edumag-pro' )
            ),
            'sports' => array(
                'value' => 'tab-sports',
                'label' => esc_html__( 'Sports', 'edumag-pro' )
            )
        );

        $title_array = array(
            esc_html__( 'Always learn something very beautiful & innovative.', 'edumag-pro' ),
            esc_html__( 'Unusual ways people pay for college', 'edumag-pro' ),
            esc_html__( 'Intoduction to  networking for beginner', 'edumag-pro' ),
            esc_html__( 'How to Prevent Stress While Studying', 'edumag-pro' ),
        );

        foreach ( $tabs as $key => $value) {

            for ( $i=1; $i<=4; $i++ ) {
                $image_index =  ( $i % 2 == 0 ) ? 2 : 1 ;
				$content[$key][$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/popular-article-0'.$image_index.'.jpg';
				$content[$key][$i]['url']          = '#';
				$content[$key][$i]['title']        = $title_array[$i-1];
				$content[$key][$i]['excerpt']      = esc_html__( 'Vestibulum interdum elit quis finibus sagittis. Proin non tristique erat. Duis vehicula, enim sitamet consequat vehicula.', 'edumag-pro' );
				$content[$key][$i]['date']         = esc_html__( 'Dec 18, 2016', 'edumag-pro' );
				$content[$key][$i]['cat_array']    = array( $value['label'] );
				$content[$key][$i]['likes']        = '<a href="#." class="like active"><span><i class="fa fa-heart"></i></span></a>';
            }
        }

      break;

      case 'category':
      	$no_of_tabs = $options['popular_articles_no_of_tabs'];

      	$cat_ids   = array();

      	for( $j=1; $j<= $no_of_tabs; $j++ ){
      		if( !empty( $options['popular_articles_content_category_'. $j ] ) ){
      			$cat_ids = array_merge( $cat_ids, array( $options['popular_articles_content_category_'. $j ] ) );
      		}
      	}

      	if( empty( $cat_ids ) ) return; // return if no category is selected

      	$args = array( 
            'category__in'   =>  $cat_ids,
            'posts_per_page' => absint( get_option( 'posts_per_page' ) ), // Maximum number of posts to show on a page; set in Reading Options.
            'meta_key'       => 'post_views_count',
            'orderby'        => 'meta_value_num',
            'order'          => 'DESC',
        );
        $all_posts = get_posts( $args );

        $k = 1;
        foreach ( $all_posts as $key => $post ) {
        	$post_id =  $post->ID;
        	$img_array = array();
            $category_array =  array();

        	if ( has_post_thumbnail( $post_id ) ) {
				$img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
			} else {
				$img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
			}

            $like_string =  '';
            if( function_exists( 'tp_education_like_button' ) ){
                $like_string = tp_education_like_button();
                $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
            }

			$content['all'][$k]['img_array']    = $img_array;
			$content['all'][$k]['url']          = get_permalink( $post_id );
			$content['all'][$k]['title']        = get_the_title( $post_id );
			$content['all'][$k]['excerpt']      = edumag_pro_trim_content( 15, $post  );
			$content['all'][$k]['date']         = get_the_date( '', $post_id );
            $content['all'][$k]['cat_array']    = get_the_category( $post_id );
			$content['all'][$k]['likes']        = $like_string;
     	$k++;
     	}

      	foreach ( $cat_ids as $key => $cat_id ) {
	        // Fetch posts.
			$args = array( 
                'cat'            => absint( $cat_id ),
                'posts_per_page' => absint( get_option( 'posts_per_page' ) ), // Maximum number of posts to show on a page; set in Reading Options.
                'meta_key'       => 'post_views_count',
                'orderby'        => 'meta_value_num',
                'order'          => 'DESC',
			);

			$category_posts = get_posts( $args );

			$i = 1;
	        foreach( $category_posts as $category_post ){
			    $post_id   = $category_post->ID;
			    $img_array = array();

			    if ( has_post_thumbnail( $post_id ) ) {
			        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-featured-popular-article' );
			    } else {
			        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
			    }

                $like_string =  '';
                if( function_exists( 'tp_education_like_button' ) ){
                    $like_string = tp_education_like_button();
                    $like_string = '<span class="screen-reader-text">' . esc_html__( 'Likes', 'edumag-pro' ) . '</span>' . $like_string;
                }

			    $content[$cat_id][$i]['img_array']    = $img_array;
			    $content[$cat_id][$i]['url']          = get_permalink( $post_id );
			    $content[$cat_id][$i]['title']        = get_the_title( $post_id );
			    $content[$cat_id][$i]['excerpt']      = edumag_pro_trim_content( 15, $category_post  );
			    $content[$cat_id][$i]['date']         = get_the_date( '', $post_id );
			    $content[$cat_id][$i]['cat_array']    = get_the_category( $post_id );
                $content[$cat_id][$i]['likes']        = $like_string;

			$i++;
	        }
      	}
      break;

      default:
      break;
    }
	
    if ( !empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Popular articles section content details.
add_filter( 'edumag_pro_filter_popular_articles_section_details', 'edumag_pro_get_popular_articles_section_details' );


if ( ! function_exists( 'edumag_pro_render_popular_articles_section' ) ) :
  /**
   * Start Popular articles section
   *
   * @return string Popular articles content
   * @since EduMag Pro 1.0
   *
   */
   function edumag_pro_render_popular_articles_section( $content_details ) {
   	if( empty(  $content_details ) ) return;

       $options                = edumag_pro_get_theme_options(); // get theme options
       $content_type           = $options['popular_articles_content_type'];
       $sidebar_layout         = edumag_pro_layout();
       $sidebar_disabled_class = !is_active_sidebar( 'popular_articles_sidebar' ) ? 'sidebar-disabled' : '';
    ?>
    <section id="popular-articles" class="page-section">
        <div class="container">
          	<div class="main-content <?php echo esc_attr( $sidebar_disabled_class ); ?>">
            <?php 
                $section_header = ( 'demo' == $content_type ) ? esc_html__( 'popular articles', 'edumag-pro' ) : $options['popular_articles_title'];
                $section_subtitle = ( 'demo' == $content_type ) ? esc_html__( 'Find the most educational and motivating articles.', 'edumag-pro' ) : $options['popular_articles_subtitle'];

                if( !empty( $section_header ) || !empty( $section_subtitle ) ){ ?>
                    <header class="entry-header wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.4s">
                    <?php 
                        if( !empty( $section_header ) ){
                            echo '<h2 class="entry-title">'. esc_html( $section_header ) .'</h2>';
                        }
                        if( !empty( $section_subtitle ) ){
                            echo '<p class="sub-title">'. esc_html( $section_subtitle ) .'</p>';
                        }
                    ?>   
                    </header><!--.entry-header-->
                <?php   
                }
            ?>
                <div class="entry-content  wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">

                  	<div class="tab-section">
    	                <ul class="tabs">
    	                <?php 
    	                	if( 'demo' == $content_type ){
    	                	echo    '<li class="tab-link active" data-tab="all-popular-article"><a href="#.">'. esc_html__( 'all', 'edumag-pro' ) .'</a></li>
    	                			<li class="tab-link" data-tab="tab-popular-article-college"><a href="#.">'. esc_html__( 'College', 'edumag-pro' ) .'</a></li>
    	                			<li class="tab-link" data-tab="tab-popular-article-careers"><a href="#.">'. esc_html__( 'Careers', 'edumag-pro' ) .'</a></li>
    	                			<li class="tab-link" data-tab="tab-popular-article-sports"><a href="#.">'. esc_html__( 'Sports', 'edumag-pro' ) .'</a></li>';
    	                	} else {
                                $cat_ids = array(); 
    	                		$no_of_tabs = $options['popular_articles_no_of_tabs'];

                                for( $i=1; $i<= $no_of_tabs; $i++ ){
                                    if( !empty( $options['popular_articles_content_category_'. $i ] ) ){
                                        $cat_ids = array_merge(  $cat_ids, array( $options['popular_articles_content_category_'. $i ] ) );
                                    }
                                }

                                if( !empty( $cat_ids ) ){
                                    echo '<li class="tab-link active" data-tab="all-popular-article"><a href="#.">'. esc_html__( 'all', 'edumag-pro' ) .'</a></li>';
                                    foreach( $cat_ids as $cat ){
                                        $cat_object = get_category( $cat );

                                        $tab_id    = 'tab-popular-article-'. $cat_object->slug;
                                        $tab_name  = get_cat_name( $cat_object->term_id );
                                    
                                        echo '<li class="tab-link" data-tab="'. esc_attr( $tab_id ) .'"><a href="#.">'. esc_html( $tab_name ) .'</a></li>';
                                    }
                                    
                                }
    	                	}
    	                ?>
    	                </ul>
                  	</div><!--.tab-section-->
                    
                    <?php 
                    foreach ( $content_details as $key => $content_detail ) :
                  	
                      	if( $key == 'all' ){
                            $section_tab_id  	  = 'all-popular-article';
                            $section_active_class = 'active';
                      	} else {
                      		if( 'demo' == $content_type ){
                      			$section_tab_id  	  = 'tab-popular-article-'. $key;
                      			$section_active_class = '';
                      		} else {
                      			$cat_object = get_category( absint( $key ) );
                      			$section_tab_id  	  = 'tab-popular-article-'. $cat_object->slug;
                      			$section_active_class = '';
                      		}
                      	}
                    ?>
                  		
                  	<div id="<?php echo esc_attr( $section_tab_id ); ?>" class="tab-content <?php echo esc_attr( $section_active_class );?>">
                    	<div class="regular row" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": false, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": false, "draggable": false }'>

                            <?php foreach ( $content_detail as $key => $content ) : ?>
                  						<div class="slider-item">    
                  							<div class="image-wrapper">
                  							  	<a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0]); ?>" alt="<?php echo esc_attr( $content['title'] );?>"></a>
                                        <p class="cat-links">
                                          <?php 
                                              if( 'demo' == $content_type ){
                                                  echo '<a href="#" class="category-name">'. esc_attr( $content['cat_array'][0] ) .'</a>';
                                              } else {
                                                  $cat_array = $content['cat_array'];
                                                  $i = 1;
                                                  foreach ($cat_array as $key => $cat ) {
                                                     echo '<a href="'. esc_url( get_category_link( $cat->term_id ) ) .'" class="category-name">'. esc_html( $cat->name ) .'</a>';
                                                     if( $i == 2 ) break;
                                                     $i++;
                                                  }
                                              }
                                          ?>
              					  	            </p><!-- .cat-links -->
                  							</div><!-- end .image-wrapper -->

        							<div class="article-contents-wrapper">
        								<div class="article-title">
        									<h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] );?></a></h2>
        									<div class="title-bottom-line"></div>
        								</div><!-- .article-title -->

        								<div class="article-desc">
        									<p><?php echo esc_html( $content['excerpt'] ); ?></p>
        								</div><!-- .article-desc -->

        								<div class="article-entry-meta">
        									<div class="pull-left">
        										<time><?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( $content['date'] ) );?></time>
        									</div><!--.pull-left-->

        									<div class="pull-right">
                            <?php
                                if( !empty( $content['likes'] ) ){
                                    echo wp_kses_post( $content['likes'] );
                                }
                            ?>
        									</div><!--.pull-right-->
        								</div><!-- .article-entry-meta -->

        							</div><!-- end .article-contents-wrapper -->
    						</div><!-- .slider-item -->
                            <?php endforeach; ?>                       
                    	</div><!-- .regular -->
                	</div><!-- #all-popular-article  -->
                	<?php endforeach; ?>

                    <?php 
                        $featured_content = array();
                        switch ( $content_type ){
                            case 'demo':
                            
                                $featured_title_array = array(
                                    esc_html__( 'Hard work is what brings success in your life.', 'edumag-pro' ),
                                    esc_html__( 'First degree courses agreed for Spain.', 'edumag-pro' ),
                                );

                                $featured_cat_array = array(
                                    esc_html__( 'Learn', 'edumag-pro' ),
                                    esc_html__( 'Abroad', 'edumag-pro' )
                                );

                                for ( $i=1; $i<=2; $i++ ) {
                                    $featured_content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/popular-article-0'. ( $i+2 ).'.jpg';
                                    $featured_content[$i]['url']          = '#';
                                    $featured_content[$i]['title']        = $featured_title_array[$i-1];
                                    $featured_content[$i]['date']         = esc_html__( 'August 15, 2016', 'edumag-pro' );
                                    $featured_content[$i]['cat_array']    = array( $featured_cat_array[$i-1] );
                                }
                            break;

                            case 'category':
                                $posts_ids = array();
                                for ( $i=1; $i<=2; $i++ ) { 
                                    if( !empty( $options['popular_articles_featured_post_'. $i ] ) ){
                                        $posts_ids = array_merge( $posts_ids , array( $options['popular_articles_featured_post_'. $i ] ) );
                                    }
                                }

                                if( !empty( $posts_ids ) ){
                                    $args = array(
                                        'post_type'           => 'post',
                                        'post__in'            => $posts_ids,
                                        'posts_per_page'      => 2,
                                    );

                                    $featured_posts = get_posts( $args );

                                    $j= 1;
                                    foreach ( $featured_posts as $key => $featured_post ) {
                                        $post_id = $featured_post->ID;
                                        $img_array = array();

                                        if ( has_post_thumbnail( $post_id ) ) {
                                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'edumag-pro-gallery-image' );
                                        } else {
                                            $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-450x300.jpg';
                                        }

                                        $featured_content[$j]['img_array']    = $img_array;
                                        $featured_content[$j]['url']          = get_permalink( $post_id );
                                        $featured_content[$j]['title']        = get_the_title( $post_id );
                                        $featured_content[$j]['date']         = get_the_date( '', $post_id );
                                        $featured_content[$j]['cat_array']    = get_the_category( $post_id );

                                        $j++;
                                    }

                                }
                            break; 

                            default:
                            break;
                        }

                    if( ! empty( $featured_content ) ) { ?>
            		<div class="row two-columns wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                        <?php foreach ( $featured_content as $key => $content) { ?>
                      	<div class="column-wrapper has-post-thumbnail"><!-- no-post-thumbnail class for no image -->
    	                    <div class="image-wrapper">
    	                    	<a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
    	                    </div><!-- end .image-wrapper -->

    	                    <div class="article-contents-wrapper">
                                <?php if( 'demo' == $content_type ){ 
                                    echo '<a href="#" class="category-name">'. esc_html( $content['cat_array'][0] ) .'</a>';
                                }else{
                                    $cat_array = $content['cat_array'];
                                    $m=1;
                                    foreach ( $cat_array as $key => $category ) {
                                        echo '<a href="'.esc_url( get_category_link( $category->term_id ) ) .'" class="category-name">'. esc_html( $category->name ).'</a>';

                                        if( $m == 2 ) break;
                                        $m++;
                                    }

                                } ?>
    							<div class="article-title">
    								<h2><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
    							</div><!-- .article-title -->

    							<div class="article-entry-meta">
    								<div class="pull-left">
    									<time><?php echo date_i18n( esc_html__( 'M d, Y', 'edumag-pro' ), strtotime( $content['date'] ) ) ?></time>
    								</div><!--.pull-left-->
    							</div><!-- .article-entry-meta -->
    	                    </div><!-- .articles-contents-wrapper -->
                      	</div><!-- .column-wrapper -->
                        <?php } ?>
                    </div><!-- .row/.two-columns -->
                    <?php }
                      
                        $advertisement_type = $options['popular_articles_ad_type'];
                        $advertisement = '';

                        if( 'disabled' != $advertisement_type ) { 

                            switch ( $advertisement_type ) {

                                case 'demo':
                                    $advertisement = '<a href="#"><img src="'. get_template_directory_uri() .'/assets/uploads/google-ad-1.jpg"></a>';
                                break;

                                case 'ad_image':
                                    $ad_image = !empty( $options['popular_articles_ad_image'] ) ? $options['popular_articles_ad_image'] : '' ;
                                    $ad_url = !empty( $options['popular_articles_ad_url'] ) ? $options['popular_articles_ad_url'] : '#' ;
                                    $new_tab = $options['popular_articles_new_tab'] ? '_blank' : '_self';

                                    if( !empty( $ad_image ) ){
                                        $advertisement = '<a href="'. esc_url( $ad_url ) .'" target="'. esc_attr( $new_tab ) .'"><img src="'. esc_url( $ad_image ) .'"></a>';
                                    }
                                break;

                                default:
                                    if( !empty( $options['popular_articles_ad_code'] ) ) {
                                        $advertisement = $options[' popular_articles_ad_code'];
                                    }
                                break; 
                            }
                        }
                    ?>
                    <?php if( !empty( $advertisement ) ){ ?>
                    <section id="google-advertisement-1" class="widget widget_google_ad  wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                        <?php 
                            if( 'ad_code' == $advertisement_type ){
                                echo html_entity_decode( $advertisement, ENT_QUOTES, 'UTF-8' );
                            } else{
                                echo wp_kses_post( $advertisement );
                            } 
                        ?>
                    </section><!-- #google-advertisment -->
                    <?php } ?>
                </div><!--.entry-content-->
            </div><!--.main-content-->
            <?php if( is_active_sidebar( 'popular_articles_sidebar' ) && ( 'no-sidebar' != $sidebar_layout ) ) : ?>
            <div class="section-sidebar wow fadeInUp" data-wow-delay="0.3s" data-wow-duration="0.3s">
                <?php dynamic_sidebar('popular_articles_sidebar'); ?>
            </div><!--.section-sidebar-->
            <?php endif; ?>

        </div><!--.container-->
    </section><!--#popular-articles-->
    <?php 
    }
endif;
