<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

$options = edumag_pro_get_theme_options();


if ( ! function_exists( 'edumag_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'edumag_pro_doctype', 'edumag_pro_doctype', 10 );

if ( ! function_exists( 'edumag_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'edumag_pro_before_wp_head', 'edumag_pro_head', 10 );

if ( ! function_exists( 'edumag_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'edumag-pro' ); ?></a>

		<?php
	}
endif;
add_action( 'edumag_pro_page_start_action', 'edumag_pro_page_start', 10 );

if ( ! function_exists( 'edumag_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'edumag_pro_page_end_action', 'edumag_pro_page_end', 10 );

if ( ! function_exists( 'edumag_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_header_start() {
		?>
		<header id="masthead" class="site-header make-sticky page-section" role="banner">
		<?php
	}
endif;
add_action( 'edumag_pro_header_action', 'edumag_pro_header_start', 10 );

if ( ! function_exists( 'edumag_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_site_branding() {
		?>
		<div class="container">
			<?php 
			$site_title = get_bloginfo( 'name' );
			$description = get_bloginfo( 'description', 'display' );

			if( has_custom_logo() || display_header_text() ): ?>
				<div class="site-branding">
					<?php if( has_custom_logo() ): ?>				
					<div class="site-logo">
	            		<?php the_custom_logo(); ?>
	          		</div>
					<?php
					endif;
					if( display_header_text() ){ ?>

					<div id="site-header">
					<?php
						if ( is_front_page() && is_home() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;

						
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; ?>
					</div><!-- #site-header -->
					<?php } ?>
				</div><!-- .site-branding -->
			<?php endif; ?>
			<div class="pull-right">
				<?php 
					if( is_active_sidebar( 'header_advertisement' ) ) :
						dynamic_sidebar( 'header_advertisement' );
					endif;
				?>
			</div><!-- .pull-right -->
		</div><!--.container-->
		<?php
	}
endif;
add_action( 'edumag_pro_header_action', 'edumag_pro_site_branding', 20 );

if ( ! function_exists( 'edumag_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_site_navigation() {
		// if( has_nav_menu( 'primary') ):
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<?php 
				$args = array( 
					'theme_location' => 'primary',
					'menu_id' => 'primary-menu',
					'container' => 'div', 
					'container_class' => 'container',
					'fallback_cb' => 'edumag_pro_menu_fallback_cb',
				);
				wp_nav_menu( $args ); ?>
		</nav><!-- #site-navigation -->

		<?php
		// endif;
	}
endif;
add_action( 'edumag_pro_header_action', 'edumag_pro_site_navigation', 30 );


if ( ! function_exists( 'edumag_pro_append_search' ) ) :
	/**
	 * Add search bar to menu
	 */

	function edumag_pro_append_search( $items, $args ) {
		if ( 'primary' == $args->theme_location ) {
			$options        = edumag_pro_get_theme_options();

		   // Search Box
		   	if ( $options['append_search'] == true ) {
		     	$search = '<div class="search" id="search">
                                '.get_search_form(false).'
                            </div>';
		   	} else {
		        $search = '';
		   	}

		   $items = $items.$search;
		}
		return $items;
	}
endif;
add_filter('wp_nav_menu_items','edumag_pro_append_search', 10, 2 );


if ( ! function_exists( 'edumag_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_header_end() {
		?>
		</header><!-- #masthead -->
		<?php
	}
endif;
add_action( 'edumag_pro_header_action', 'edumag_pro_header_end', 50 );

if ( ! function_exists( 'edumag_pro_mobile_menu' ) ) :
	/**
	 * Mobile menu  html codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_mobile_menu() {
		if( has_nav_menu( 'primary' ) ):
			$args = array( 
					'theme_location' => 'primary',
					'menu_id' => 'primary-menu',
					'container' => 'false'
			);
		?>
		<!-- Mobile Menu -->
    	<nav id="sidr-left-top" class="mobile-menu sidr left">
    		<?php if( has_custom_logo() ): ?>
      		<div class="site-branding text-center">
          		<div class="site-logo">
            		<?php echo get_custom_logo(); ?>
          		</div><!-- end .site-logo -->
      		</div><!-- end .site-branding -->
      		<?php endif; 
				wp_nav_menu( $args );
      		?>
	    </nav><!-- end left-menu -->

	    <a id="sidr-left-top-button" class="menu-button right" href="#sidr-left-top"><i class="fa fa-bars"></i></a>
		<?php
	endif;
	}
endif;
add_action( 'edumag_pro_after_header', 'edumag_pro_mobile_menu', 10 );


if ( ! function_exists( 'edumag_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'edumag_pro_content_start_action', 'edumag_pro_content_start', 10 );

if ( ! function_exists( 'edumag_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'edumag_pro_content_end_action', 'edumag_pro_content_end', 10 );

if ( ! function_exists( 'edumag_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_loader() {
		$options = edumag_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
	         <div class="loader-container">
         		<i class="fa <?php echo esc_attr( $options['loader_icon'] );?> fa-spin"></i>
	         </div>
	     	</div><!-- end loader -->
		<?php }
	}
endif;
add_action( 'edumag_pro_before_header', 'edumag_pro_loader', 10 );

if( !function_exists( 'edumag_pro_top_header') ):
	/**
	 * Start top bar section #top-bar
	 *
	 * @since EduMag Pro 1.0 
	 *
	 */
	function edumag_pro_top_header(){ 
		$options = edumag_pro_get_theme_options();

		if( $options['enable_top_header'] ) :
		?>
		<section id="top-bar" style="background-color:#293035;">
		    <button class="topbar-toggle"><i class="fa fa-angle-left"></i></button>
	      	<div class="container topbar-dropdown">
	      		<?php if( $options['enable_address_block'] ) : ?> 
	        	<div class="pull-left">
	        		<?php 
	        			$address_block = array();

	        			$address_block['phone'] = !empty( $options['contact_phone_icon'] ) ? '<i class="fa '. esc_attr( $options['contact_phone_icon'] ) .'"></i>' : '';
	        			$address_block['phone'] .= !empty( $options['contact_phone_number'] ) ? '<a href="tel:'. preg_replace('/\D+/', '', $options['contact_phone_number'] ) .'">'. esc_html( $options['contact_phone_number'] ) .'</a>' : ''; 

	        			$address_block['email'] = !empty( $options['contact_email_icon'] ) ? '<i class="fa '. esc_attr( $options['contact_email_icon'] ) .'"></i>' : '';
	        			$address_block['email'] .= !empty( $options['contact_email'] ) ? '<a href="mailto:'.  esc_attr( $options['contact_email'] ) .'">'. esc_html( $options['contact_email'] ) .'</a>' : ''; 

	        			$address_block['skype'] = !empty( $options['skype_icon'] ) ? '<i class="fa '. esc_attr( $options['skype_icon'] ) .'"></i>' : '';
	        			$address_block['skype'] .= !empty( $options['skype_link'] ) ? '<a href="skype:'.  esc_attr( $options['skype_link'] ) .'">'. esc_html( $options['skype_link'] ) .'</a>' : '';
	        		?>
					<ul class="address-block">
						<?php foreach ($address_block as $key => $value) {
							if( !empty( $value ) )
								echo '<li>'. $value . '</li>';
						} ?>
					</ul><!-- end .address-block -->
	        	</div><!-- end .pull-left -->
				<?php endif; ?>

	        	<?php if( $options['enable_custom_link_block'] || $options['enable_social_link_block'] ) : ?>
		        <div class="pull-right">
		        	<?php if( $options['enable_custom_link_block'] ){ ?>
		          	<ul class="login-signup">
		          		<?php 
		          			for( $i=1; $i<= $options['no_of_custom_link']; $i++ ){
		          				$custom_link = !empty( $options['custom_link_'. $i ] ) ? $options['custom_link_'. $i ] : '#';
		          				$link_text = !empty( $options['link_text_'. $i ] ) ? $options['link_text_'. $i ] : '';

		          				if( !empty( $link_text ) ){
		          					echo '<li><a href="'. esc_url( $custom_link ).'">'. esc_html( $link_text ) .'</a></li>';
		          				}
		          			}
		          		?>
		            	
		          	</ul><!--login-signup-->
		          	<?php }
		          	if( $options['enable_social_link_block'] ){ ?>
		          	<ul class="social-icons">
		          		<?php 
		          			for( $i=1; $i<= $options['no_of_social_link']; $i++ ){
		          				$social_link  =  !empty( $options['social_link_'. $i ] ) ? $options['social_link_'. $i ] : '';
		          				if( !empty( $social_link ) ){
		            				echo '<li><a href="'. esc_url( $social_link ).'"></a></li>';
		          				}
		          			}
		          		?>
		            	
		          	</ul><!--.social-icon-->
		          	<?php } ?>
		        </div><!-- end .pull-right -->
		    	<?php endif; ?>
	      	</div><!-- end .container -->
		</section><!-- #top-bar -->
	<?php 
 		endif;
 	}
endif;
add_action( 'edumag_pro_before_header', 'edumag_pro_top_header', 20); 

if ( ! function_exists( 'edumag_pro_add_breadcrumb' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_add_breadcrumb() {
		$options = edumag_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		// Bail if Home Page.
		if ( is_front_page() && !is_home() ) {
			return;
		}

		echo '<div id="breadcrumb-list" class="os-animation" data-os-animation="fadeInUp">';
				/**
				 * edumag_pro_simple_breadcrumb hook
				 *
				 * @hooked edumag_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'edumag_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}

endif;
add_action( 'edumag_pro_add_breadcrumb', 'edumag_pro_add_breadcrumb' , 30 );

if ( ! function_exists( 'edumag_pro_get_footer_content' ) ) :

	/**
	 * Add breadcrumb.
	 *
	 * @since EduMag Pro 1.0
	 */
	function edumag_pro_get_footer_content() { 
		$options = edumag_pro_get_theme_options(); // get theme options
		$footer_sidebar_data    = edumag_pro_footer_sidebar_class();
		$footer_sidebar_class   = $footer_sidebar_data['class'];
		$footer_sidebar_widgets = $footer_sidebar_data['active_sidebar'];
	?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			<?php if ( !empty( $footer_sidebar_widgets ) ) : ?>			
			<div class="container page-section">
				<div class="row <?php echo esc_attr( $footer_sidebar_class ); ?>">

				<?php foreach( $footer_sidebar_widgets as $active_widget ) : ?>
					<div class="column-wrapper">
					<?php 
		      			if ( is_active_sidebar( esc_html( $active_widget ) ) ){
		      				dynamic_sidebar( esc_html( $active_widget ) );
		      			}
		      		?>
					</div><!-- .column-wrapper -->
				<?php endforeach; ?>

				</div><!-- .row -->
        	</div><!-- .container -->
        	<?php endif; ?>
        	
        	<div class="clear"></div>
			<div class="bottom-footer">
				<div class="container">
				<?php if( !empty( $options['copyright_text'] ) ): 
					$search = array( '[the-year]', '[site-link]' );
	        		$replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );
	        		$options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
				?>
					<div class="site-info">
						<p>
							<?php 
							echo wp_kses_post( $options['copyright_text'] ); 
							if ( function_exists( 'the_privacy_policy_link' ) ) {
							    the_privacy_policy_link( ' | ' );
							}
							?>
						</p>
					</div><!-- .site-info -->
				<?php endif; ?>
				</div><!-- .container -->
			</div><!--.bottom-footer-->
		</footer><!-- #colophon -->
	<?php } 
endif;
add_action( 'edumag_pro_footer_content', 'edumag_pro_get_footer_content' );


if ( ! function_exists( 'edumag_pro_back_to_top' ) ) :
	/**
	 * Back to top option
	 *
	 * @since EduMag Pro 1.0
	 *
	 */
	function edumag_pro_back_to_top() { 
		$options = edumag_pro_get_theme_options();
		if ( $options['scroll_top_visible'] === true ) : ?>
			<div class="backtotop"><i class="fa fa-angle-up"></i></div><!-- .backtotop -->
		<?php
		endif;
	}
endif;
add_action( 'edumag_pro_back_to_top', 'edumag_pro_back_to_top', 10 );